@@ -10,7 +10,10 @@ pub(crate) enum TypeID {
     Int = 1,
     FloatingPoint = 2,
     Binary = 3,
+    // LargeBinary = 3,
+    // FixedSizeBinary = 3,
     Utf8 = 4,
+    // LargeUtf8 = 4,
     Bool = 5,
     Decimal = 6,
     Date = 7,
@@ -18,15 +21,12 @@ pub(crate) enum TypeID {
     Timestamp = 9,
     Interval = 10,
     List = 11,
+    // LargeList = 11,
+    // FixedSizeList = 11,
     Struct = 12,
     Union = 13,
-    FixedSizeBinary = 14,
-    FixedSizeList = 15,
     Map = 16,
     Duration = 17,
-    //LargeBinary = 3,
-    //LargeUtf8 = 4,
-    //LargeList = 11,
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////
@@ -155,13 +155,14 @@ pub(crate) fn hash_data_type<Dig: Digest>(data_type: &DataType, hasher: &mut Dig
         DataType::Duration(_) => unimplemented!(),
         DataType::Interval(_) => unimplemented!(),
         DataType::Binary | DataType::FixedSizeBinary(_) | DataType::LargeBinary => {
-            unimplemented!()
+            hasher.update(&(TypeID::Binary as u16).to_le_bytes());
         }
         DataType::Utf8 | DataType::LargeUtf8 => {
             hasher.update(&(TypeID::Utf8 as u16).to_le_bytes());
         }
-        DataType::List(_) | DataType::FixedSizeList(..) | DataType::LargeList(_) => {
-            unimplemented!()
+        DataType::List(field) | DataType::FixedSizeList(field, _) | DataType::LargeList(field) => {
+            hasher.update(&(TypeID::List as u16).to_le_bytes());
+            hash_data_type(field.data_type(), hasher);
         }
         DataType::Struct(_) => unimplemented!(),
         DataType::Union(_) => unimplemented!(),
@@ -177,33 +178,3 @@ pub(crate) fn hash_data_type<Dig: Digest>(data_type: &DataType, hasher: &mut Dig
         DataType::Map(..) => unimplemented!(),
     }
 }
-
-pub(crate) fn get_fixed_size(data_type: &DataType) -> Option<usize> {
-    match data_type {
-        DataType::Null => unimplemented!(),
-        DataType::Boolean => None,
-        DataType::Int8 | DataType::UInt8 => Some(1),
-        DataType::Int16 | DataType::UInt16 => Some(2),
-        DataType::Int32 | DataType::UInt32 => Some(4),
-        DataType::Int64 | DataType::UInt64 => Some(8),
-        DataType::Float16 => Some(2),
-        DataType::Float32 => Some(4),
-        DataType::Float64 => Some(8),
-        DataType::Timestamp(_, _) => Some(8),
-        DataType::Date32 => Some(4),
-        DataType::Date64 => Some(8),
-        DataType::Time32(_) => Some(4),
-        DataType::Time64(_) => Some(8),
-        DataType::Duration(_) => unimplemented!(),
-        DataType::Interval(_) => unimplemented!(),
-        DataType::Binary | DataType::FixedSizeBinary(_) | DataType::LargeBinary => None,
-        DataType::Utf8 | DataType::LargeUtf8 => None,
-        DataType::List(_) | DataType::FixedSizeList(..) | DataType::LargeList(_) => None,
-        DataType::Struct(_) => unimplemented!(),
-        DataType::Union(_) => unimplemented!(),
-        DataType::Dictionary(..) => unimplemented!(),
-        DataType::Decimal(_, _) => Some(16), // TODO: arrow-rs does not support 256bit decimal
-        #[cfg(not(feature = "use-arrow-5"))]
-        DataType::Map(..) => unimplemented!(),
-    }
-}
