@@ -1,7 +1,10 @@
-use crate::arrow_shim::{
-    array::Array,
-    datatypes::{DataType, Schema},
-    record_batch::RecordBatch,
+use crate::{
+    arrow_shim::{
+        array::Array,
+        datatypes::{DataType, Schema},
+        record_batch::RecordBatch,
+    },
+    bitmap_slice::BitmapSlice,
 };
 use digest::{Output, OutputSizeUser};
 
@@ -15,6 +18,6 @@ pub trait RecordDigest: OutputSizeUser {
 pub trait ArrayDigest: OutputSizeUser {
     fn digest(array: &dyn Array) -> Output<Self>;
     fn new(data_type: &DataType) -> Self;
-    fn update(&mut self, array: &dyn Array);
+    fn update(&mut self, array: &dyn Array, parent_null_bitmap: Option<BitmapSlice>);
     fn finalize(self) -> Output<Self>;
 }
